package app;

import java.util.Timer;
import java.util.TimerTask;

import com.is2t.mwt.composites.BorderComposite;
import com.is2t.mwt.composites.GridComposite;
import com.is2t.mwt.widgets.LookExtension;
import com.is2t.mwt.widgets.button.Button;
import com.is2t.mwt.widgets.label.TitleLabel;
import com.is2t.mwt.widgets.spinner.MultipleSpinner;
import com.is2t.mwt.widgets.spinner.int_.EndlessIntegerValue;
import com.is2t.mwt.widgets.spinner.int_.IntegerWheel;

import ej.microui.Listener;
import ej.microui.MicroUI;
import ej.microui.io.Leds;
import ej.mwt.Desktop;
import ej.mwt.MWT;
import ej.mwt.Panel;

public class Main {
	
	private static TitleLabel clockLabel;
	private static IntegerWheel hourWheel;
	private static IntegerWheel minuteWheel;
	private static IntegerWheel secondWheel;
	private static RTC rtc;
	
	public static void main(String[] args) {
		
		MicroUI.errorLog(true);
		rtc = new RTC();
		
		MWT.RenderingContext.add(new MyTheme());
		Desktop desktop = new Desktop();
		Panel panel = new Panel();
		GridComposite gc = new GridComposite(MWT.VERTICAL, 3);
		System.out.println(ej.microui.io.DisplayFont.getAllFonts().length);
		clockLabel = new TitleLabel(rtc.createTimeString());
		clockLabel.setFontSize(LookExtension.GET_X_BIG_FONT_INDEX);
		gc.add(clockLabel);
		
		MultipleSpinner ms = new MultipleSpinner();
		hourWheel = new IntegerWheel();
		EndlessIntegerValue v1 = new EndlessIntegerValue(0, 23, 1, 0, "");
		hourWheel.setModel(v1);
		ms.add(hourWheel);
		
		minuteWheel = new IntegerWheel(false, 3);
		EndlessIntegerValue v2 = new EndlessIntegerValue(0, 59, 1, 0, ""); 
		minuteWheel.setModel(v2);
		ms.add(minuteWheel);
		
		secondWheel = new IntegerWheel(false, 3);
		EndlessIntegerValue v3 = new EndlessIntegerValue(0, 59, 1, 0, ""); 
		secondWheel.setModel(v3);
		ms.add(secondWheel);
		gc.add(ms);
		
		BorderComposite bc =new BorderComposite(MWT.HORIZONTAL);
		GridComposite bgc = new GridComposite(MWT.VERTICAL, 2);
		
		Button timeButton = new Button("Set Time");
		timeButton.setListener(new Listener() {
			
			@Override
			public void performAction(int value, Object object) {
				rtc.setTime(secondWheel.getValue(), minuteWheel.getValue(), hourWheel.getValue());
				String time = rtc.createTimeString();
				Main.clockLabel.setText(time);
			}
			
			@Override
			public void performAction(int value) {
			}
			
			@Override
			public void performAction() {
			}
		});
		bgc.add(timeButton);
		
		Button alarmButton = new Button("Set Alarm");
		alarmButton.setListener(new Listener() {
			
			
			@Override
			public void performAction(int value, Object object) {
				rtc.setAlarmTime(secondWheel.getValue(), minuteWheel.getValue(), hourWheel.getValue());
				Leds.setLedOff(0);
			}
			
			@Override
			public void performAction(int value) {
			}
			
			@Override
			public void performAction() {
			}
		});
		bgc.add(alarmButton);
		
		bc.addAt(bgc, MWT.CENTER);
		gc.add(bc);
		
		panel.setWidget(gc);
		panel.show(desktop, true);
		desktop.show();		
		
		Timer tim = new Timer();
		tim.schedule(new TimerTask() {
			
			@Override
			public void run() {
				rtc.readTime();
				String time = rtc.createTimeString();
				Main.clockLabel.setText(time);
				if(rtc.checkAlarm())
					Leds.setLedOn(0);
			}
		}, 0, 1000);
	}
}
